@@ -1,6 +1,6 @@
 from collections import defaultdict
+from contextlib2 import asynccontextmanager
 
-from ..aioctxlib import aiocontextmanager
 from ..patterns import var_pattern
 
 
@@ -86,7 +86,12 @@ class AsyncPGAdapter:
                 result = record_class(**dict(result))
         return result
 
-    @aiocontextmanager
+    async def select_value(self, conn, query_name, sql, parameters):
+        parameters = self.maybe_order_params(query_name, parameters)
+        async with MaybeAcquire(conn) as connection:
+            return await connection.fetchval(sql, *parameters)
+
+    @asynccontextmanager
     async def select_cursor(self, conn, query_name, sql, parameters):
         parameters = self.maybe_order_params(query_name, parameters)
         async with MaybeAcquire(conn) as connection:
@@ -116,4 +121,4 @@ class AsyncPGAdapter:
     @staticmethod
     async def execute_script(conn, sql):
         async with MaybeAcquire(conn) as connection:
-            await connection.execute(sql)
+            return await connection.execute(sql)
